==> lms-1.0pre1.tar.gz: lms/modules/netremap.php <==
<? // $Id: netremap.php,v 1.1 2002/11/25 19:28:02 lukasz Exp $

/*
 * LMS version 1.0
 *
 *  (C) Copyright 2002 Rulez.PL Development Team
 *  (C) Copyright 2001-2002 NetX ACN
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: netremap.php,v 1.1 2002/11/25 19:28:02 lukasz Exp $
 */

if(!$LMS->NetworkExists($_GET[id])||!$LMS->NetworkExists($_GET[mapto]))
{
	header("Location: ?m=netlist");
	exit(0);
}

$network[source] = $LMS->GetNetworkRecord($_GET[id]);
$network[dest] = $LMS->GetNetworkRecord($_GET[mapto]);

if($network[source][assigned] > $network[dest][free])
	$error[remap] = TRUE;

if(!$error)
{
	if($_GET[is_sure])
	{

		$LMS->NetworkRemap($network[source][id],$network[dest][id]);
		header("Location: ?m=netinfo&id=".$network[dest][id]);
		exit(0);

	}else{
		$layout[pagetitle]="Readresowanie sieci ".strtoupper($network[source][name]);
		$SMARTY->assign("layout",$layout);
		$SMARTY->display("header.html");
		echo "<H1>Readresowanie sieci ".strtoupper($network[source][name])."</H1>";
		echo "<p>Jeste pewien e chcesz przeadresowa sie ".strtoupper($network[source][name])." (".$network[source][address]."/".$network[source][prefix].") do sieci ".strtoupper($network[dest][name])." (".$network[dest][address]."/".$network[dest][prefix].") ?</p>";
		echo "<a href=\"?m=netremap&id=".$_GET[id]."&mapto=".$_GET[mapto]."&is_sure=1\">Tak, jestem pewien</A>";
		$SMARTY->display("footer.html");
	}
}else{
	$networks = $LMS->GetNetworks();
	$SMARTY->assign("layout",$layout);
	$SMARTY->assign("network",$network[source]);
	$SMARTY->assign("networks",$networks);
	$SMARTY->assign("error",$error);
	$SMARTY->display("header.html");
	$SMARTY->display("netinfo.html");
	$SMARTY->display("footer.html");
}
	
?>

==> lms-1.1.2b.tar.gz: lms/modules/netremap.php <==
<?php

/*
 * LMS version 1.1.2b
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: netremap.php,v 1.16 2003/08/24 13:12:54 lukasz Exp $
 */

if(!$LMS->NetworkExists($_GET[id])||!$LMS->NetworkExists($_GET[mapto]))
{
	header("Location: ?m=netlist");
	die;
}

$network[source] = $LMS->GetNetworkRecord($_GET[id]);
$network[dest] = $LMS->GetNetworkRecord($_GET[mapto]);

if($network[source][assigned] > $network[dest][free])
	$error[remap] = TRUE;

if(!$error)
{
	if($_GET[is_sure])
	{

		$LMS->NetworkRemap($network[source][id],$network[dest][id]);
		header("Location: ?m=netinfo&id=".$network[dest][id]);
		die;

	}else{
		$layout[pagetitle]="Readresowanie sieci ".strtoupper($network[source][name]);
		$SMARTY->assign("layout",$layout);
		$SMARTY->display("header.html");
		echo "<H1>Readresowanie sieci ".strtoupper($network[source][name])."</H1>";
		echo "<p>Jeste pewien e chcesz przeadresowa sie ".strtoupper($network[source][name])." (".$network[source][address]."/".$network[source][prefix].") do sieci ".strtoupper($network[dest][name])." (".$network[dest][address]."/".$network[dest][prefix].") ?</p>";
		echo "<a href=\"?m=netremap&id=".$_GET[id]."&mapto=".$_GET[mapto]."&is_sure=1\">Tak, jestem pewien</A>";
		$SMARTY->display("footer.html");
	}
}else{
	$networks = $LMS->GetNetworks();
	$SMARTY->assign("layout",$layout);
	$SMARTY->assign("network",$network[source]);
	$SMARTY->assign("networks",$networks);
	$SMARTY->assign("error",$error);
	$SMARTY->display("netinfo.html");
}
	
/*
 * $Log: netremap.php,v $
 * Revision 1.16  2003/08/24 13:12:54  lukasz
 * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
 *   redhat's :>
 *
 * Revision 1.15  2003/08/18 16:52:19  lukasz
 * - added CVS Log tags
 *
 */
?>
